pycocoa.colors.GrayScaleColor

Package pycocoa :: Module colors :: Class GrayScaleColor |
[frames] | no frames]

# Class GrayScaleColor

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                           Color --+
                                   |
                                  GrayScaleColor

Color in the Gray-Scale space.

Instance Methods
Inherited from `Color`: `__init__`, `copy`, `toCMY3`, `toHSB3`, `toRGB3` Inherited from `baseTypes._Type0`: `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
| __slotnames__ = ``[``]``

Properties
| black Get the black component (`float`) or `None` if not applicable.
| white Get the white component (`float`) or `None` if not applicable.
Inherited from `Color`: `alpha`, `blue`, `brightness`, `colorSpace`, `cyan`, `green`, `hex`, `hue`, `magenta`, `n`, `name`, `nsColor`, `red`, `saturation`, `yellow` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Property Details

### black Get the black component (`float`) or `None` if not applicable. Get Method: black(self) - Get the black component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.

### white Get the white component (`float`) or `None` if not applicable. Get Method: white(self) - Get the white component (`float`) or `None` if not applicable. Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.